@@ -3,8 +3,10 @@
 
 """Responsible AI SDK package."""
 
+# ModelTask is only imported for backwards compatibility
+from raiutils.models import ModelTask
 from responsibleai.modelanalysis import ModelAnalysis
-from responsibleai.rai_insights import ModelTask, RAIInsights
+from responsibleai.rai_insights import RAIInsights
 
 from .__version__ import version
 from .feature_metadata import FeatureMetadata
