@@ -8,6 +8,7 @@ from typing import Any, Dict, List, Optional, Union
 class TaskType(str, Enum):
     CLASSIFICATION = 'classification'
     REGRESSION = 'regression'
+    FORECASTING = 'forecasting'
 
 
 class Dataset:
@@ -25,6 +26,9 @@ class Dataset:
     feature_metadata: Optional[Dict[str, Any]]
     data_balance_measures: Dict[str, Any]
     images: Optional[List[str]]
+    index: Optional[List[str]]
+    object_detection_true_y: Optional[List]
+    object_detection_predicted_y: Optional[List]
 
 
 class BoundedCoordinates:
