@@ -9,6 +9,7 @@ import numpy as np
 import pandas as pd
 from econml.solutions.causal_analysis import CausalAnalysis
 
+from raiutils.models import ModelTask
 from responsibleai._data_validations import validate_train_test_categories
 from responsibleai._internal.constants import (CausalManagerKeys,
                                                ListProperties, ManagerNames)
@@ -21,7 +22,6 @@ from responsibleai._tools.shared.state_directory_management import \
 from responsibleai.exceptions import UserConfigValidationException
 from responsibleai.feature_metadata import FeatureMetadata
 from responsibleai.managers.base_manager import BaseManager
-from responsibleai.rai_insights.constants import ModelTask
 
 
 class CausalManager(BaseManager):
