@@ -3,7 +3,8 @@
 
 """Implementation of Model Analysis API."""
 
-from responsibleai.modelanalysis.constants import ModelTask
+# ModelTask is only imported for backwards compatibility
+from raiutils.models import ModelTask
 from responsibleai.modelanalysis.model_analysis import ModelAnalysis
 
 __all__ = ["ModelAnalysis", "ModelTask"]
