@@ -3,7 +3,8 @@
 
 """Implementation of Model Analysis API."""
 
-from responsibleai.rai_insights.constants import ModelTask
+# ModelTask is only imported for backwards compatibility.
+from raiutils.models import ModelTask
 from responsibleai.rai_insights.rai_insights import RAIInsights
 
 __all__ = ['ModelTask', 'RAIInsights']
