@@ -7,7 +7,7 @@ import pandas as pd
 import pytest
 from jsonschema import ValidationError
 
-from responsibleai import ModelTask
+from raiutils.models import ModelTask
 from responsibleai._tools.causal.causal_result import CausalResult
 from responsibleai._tools.shared.versions import CausalVersions
 from responsibleai.managers.causal_manager import CausalManager
