@@ -6,7 +6,7 @@ import pandas as pd
 import pytest
 from econml.solutions.causal_analysis._causal_analysis import CausalAnalysis
 
-from responsibleai import ModelTask
+from raiutils.models import ModelTask
 from responsibleai._interfaces import (CausalConfig, CausalData, CausalPolicy,
                                        CausalPolicyGains,
                                        CausalPolicyTreeInternal,
